@@ -4,12 +4,12 @@ Declare the abstract base class for tox environments that handle the Python lang
 from __future__ import annotations
 
 import logging
+import re
 import sys
 from abc import ABC, abstractmethod
 from pathlib import Path
 from typing import Any, List, NamedTuple, cast
 
-from packaging.tags import INTERPRETER_SHORT_NAMES
 from virtualenv.discovery.py_spec import PythonSpec
 
 from tox.config.main import Config
@@ -47,6 +47,16 @@ class PythonInfo(NamedTuple):
         return f"{self.version_info.major}.{self.version_info.minor}"
 
 
+PY_FACTORS_RE = re.compile(
+    r"""
+    ^(?!py$)                                               # don't match 'py' as it doesn't provide any info
+    (?P<impl>py|pypy|cpython|jython|rustpython|ironpython) # the interpeter; most users will simply use 'py'
+    (?P<version>[2-9]\.?[0-9]?[0-9]?)?$                    # the version; one of: MAJORMINOR, MAJOR.MINOR
+    """,
+    re.VERBOSE,
+)
+
+
 class Python(ToxEnv, ABC):
     def __init__(self, create_args: ToxEnvCreateArgs) -> None:
         self._base_python: PythonInfo | None = None
@@ -127,13 +137,12 @@ class Python(ToxEnv, ABC):
         base_python = None if env_name is None else self.extract_base_python(env_name)
         return [sys.executable if base_python is None else base_python]
 
-    @staticmethod
-    def extract_base_python(env_name: str) -> str | None:
+    @classmethod
+    def extract_base_python(cls, env_name: str) -> str | None:
         candidates: list[str] = []
         for factor in env_name.split("-"):
-            spec = PythonSpec.from_string_spec(factor)
-            impl = spec.implementation or "python"
-            if impl.lower() in INTERPRETER_SHORT_NAMES and env_name is not None and spec.path is None:
+            match = PY_FACTORS_RE.match(factor)
+            if match:
                 candidates.append(factor)
         if candidates:
             if len(candidates) > 1:
@@ -141,24 +150,27 @@ class Python(ToxEnv, ABC):
             return next(iter(candidates))
         return None
 
-    @staticmethod
-    def _validate_base_python(env_name: str, base_pythons: list[str], ignore_base_python_conflict: bool) -> list[str]:
-        elements = {env_name}  # match with full env-name
-        elements.update(env_name.split("-"))  # and also any factor
-        for candidate in elements:
-            spec_name = PythonSpec.from_string_spec(candidate)
-            if spec_name.implementation and spec_name.implementation.lower() not in INTERPRETER_SHORT_NAMES:
-                continue
+    @classmethod
+    def _validate_base_python(
+        cls,
+        env_name: str,
+        base_pythons: list[str],
+        ignore_base_python_conflict: bool,
+    ) -> list[str]:
+        env_base_python = cls.extract_base_python(env_name)
+        if env_base_python is not None:
+            spec_name = PythonSpec.from_string_spec(env_base_python)
             for base_python in base_pythons:
                 spec_base = PythonSpec.from_string_spec(base_python)
                 if any(
                     getattr(spec_base, key) != getattr(spec_name, key)
                     for key in ("implementation", "major", "minor", "micro", "architecture")
-                    if getattr(spec_base, key) is not None and getattr(spec_name, key) is not None
+                    if getattr(spec_name, key) is not None
                 ):
                     msg = f"env name {env_name} conflicting with base python {base_python}"
                     if ignore_base_python_conflict:
-                        return [env_name]  # ignore the base python settings
+                        # ignore the base python settings and return the thing that looks like a Python version
+                        return [env_base_python]
                     raise Fail(msg)
         return base_pythons
 
@@ -231,27 +243,29 @@ class Python(ToxEnv, ABC):
     @property
     def base_python(self) -> PythonInfo:
         """Resolve base python"""
+        base_pythons: list[str] = self.conf["base_python"]
+
         if self._base_python_searched is False:
-            base_pythons: list[str] = self.conf["base_python"]
             self._base_python_searched = True
             self._base_python = self._get_python(base_pythons)
-            if self._base_python is None:
-                if self.core["skip_missing_interpreters"]:
-                    raise Skip(f"could not find python interpreter with spec(s): {', '.join(base_pythons)}")
-                raise NoInterpreter(base_pythons)
-            if self.journal:
+            if self._base_python is not None and self.journal:
                 value = self._get_env_journal_python()
                 self.journal["python"] = value
+
+        if self._base_python is None:
+            if self.core["skip_missing_interpreters"]:
+                raise Skip(f"could not find python interpreter with spec(s): {', '.join(base_pythons)}")
+            raise NoInterpreter(base_pythons)
+
         return cast(PythonInfo, self._base_python)
 
     def _get_env_journal_python(self) -> dict[str, Any]:
-        assert self._base_python is not None
         return {
-            "implementation": self._base_python.implementation,
+            "implementation": self.base_python.implementation,
             "version_info": tuple(self.base_python.version_info),
-            "version": self._base_python.version,
-            "is_64": self._base_python.is_64,
-            "sysplatform": self._base_python.platform,
+            "version": self.base_python.version,
+            "is_64": self.base_python.is_64,
+            "sysplatform": self.base_python.platform,
             "extra_version_info": None,
         }
 
