@@ -30,6 +30,9 @@ def complex_example() -> str:
     py, d: space
     extra: extra
     more-default
+    no:space
+    trailingcolon:
+    tab:\ttab
     """,
     )
 
@@ -49,6 +52,8 @@ def test_factor_env_discover(complex_example: str) -> None:
         "c",
         "d",
         "extra",
+        "trailingcolon",
+        "tab",
     ]
 
 
@@ -66,6 +71,8 @@ def test_factor_env_discover(complex_example: str) -> None:
         "pi-b-dev",
         "c",
         "extra",
+        "trailingcolon",
+        "tab",
     ],
 )
 def test_factor_env_filter(env: str, complex_example: str) -> None:
@@ -73,6 +80,7 @@ def test_factor_env_filter(env: str, complex_example: str) -> None:
     assert "default" in result
     assert "lines" in result
     assert "more-default" in result
+    assert "no:space" in result
     if "py" in env:
         assert "py only" in result
         assert "not py" not in result
